function results = AngleSpline(tss)
%results = AngleSpline(timestep)
% Input: 
%      tss: time step size, unit in [ms] 
% Output:
%      results: rotational angle of each cervical vertebra at each time
%      step.
% This funcation calculate ratational angle of each cervical vertebra at
% each time step. Only C2 to C6 are recorded in the experiment. The 
% calculation results are saved in file "angle.mat". The initial
% data is set according to Ono,K.etc.(2000) "Cervical Injury Mechanism 
% Based on the Analysis of Human Cervical
% Vertebral Motion and Head-Neck-Torso Kinematices During Low Speed Rear
% Impacts, Frontiers in Whiplash Trauma 2000,vol 38,p372-p388". The figure
% is also available in Liu,F. and Yang, J. "Modeling of Whiplash Injuries
% using CFD" (Figure 11), which can be downloaded at 
% "http://www.tfd.chalmers.se/~lada/postscript_files/
% thesis_Modeling-of-Whiplash-Injuries-using-CFD.pdf" 
%
% This function is developed in September 2007
%  Feng Liu
%  Vehicle Safety Division
%  Chalmers University of Technology
%  liu.peak@gmail.com
% Revisions
%--------------------
% February 2009, add comments, remove the plot part
%% Initialize time vector and rotational angles
timeNode = [0 25 50 65 100 150 200 250 300];   %[ms]
time = timeNode / 1000;                        %[s]
tss = tss / 1000;                              %Convert from [ms] to [s]
time_vec = time(1) : tss : time(end);          %time step size

c1=[0 -1   -3   -5   3 20 33 43 47];
c2=[0 -1   -3   -5   3 20 33 43 47];
c3=[0 -1   -3   -6   0 21 33 37 43];
c4=[0 -2   -4   -7   3 24 34 35 34];
c5=[0 -0.7 -1.5 -2.5 8 27 36 33 26];
c6=[0  0.1  0.3  3  18 33 32 27 24];
t1 = zeros(1,9);   
%t1 represents T1(thorax vertebra 1) which assumed remains no movement
%during the collision. 

angle = [t1; c6; c5; c4; c3; c2; c1];

results = zeros((max(timeNode)*(1/tss)/1000+1),7);

for bone_id = 2:7
    results(:,bone_id) = spline(time,angle(bone_id,:), time_vec);
end

save angle.mat results
save angle.txt results