function iFig = WhiplashMovie(iFig,timestep,x_b,y_b,x_v,y_v)
%iFig = WhiplashMovie(iFig,timestep)
%iFig = WhiplashMovie(iFig,timestep,x_b,y_b,x_v,y_v)
% Input:
%      iFig: figure index
%      timestep: time step size [ms]
%      x_b: x coordinate matrix of the vertebrae
%      y_b: y coordinate matrix of the vertebrae
%      x_v: x coordinate matrix of the key nodes on the blood vessel
%      y_v: y coordinate matrix of the key nodes on the blood vessel
% This function shows the calculated whiplash movement as an animation, and
% also plots the key frames.
%
% This function is developed in September 2007
%  Feng Liu
%  Vehicle Safety Division
%  Chalmers University of Technology
%  liu.peak@gmail.com
% Revisions
%--------------------
% February 2009, add comments, modified from a .m file to a function

if nargin == 2
    x_b = load('vertebra_node_x.mat');
    y_b = load('vertebra_node_y.mat');
    x_v = load('vessel_node_x.mat');
    y_v = load('vessel_node_y.mat');
end

y_b(:,1) = 0;
time_len = length(x_v);
ts = 1 : time_len;

figure(iFig)
iFig = iFig + 1;

subplot(1,3,2)
mydraw_b = plot (x_b(ts,:),y_b(ts,:),'g-s','EraseMode','xor');%vertebrae
title('Vertebra')
axis([-0.08 0.04 0 0.12])


subplot(1,3,1)
mydraw_v=plot (x_v(ts,:),y_v(ts,:),'r-^','EraseMode','xor');%blood vessel
title('BVessel')
axis([-0.08 0.04 0 0.12])

for i_ts=1:time_len
    set(mydraw_b,'xdata',x_b(i_ts,:),'ydata',y_b(i_ts,:));
    set(mydraw_v,'xdata',x_v(i_ts,:),'ydata',y_v(i_ts,:));
    drawnow
end
% Show final shape

subplot(1,3,3)
plot(x_b(end,:),y_b(end,:),'g-s',x_v(end,:),y_v(end,:),'r-^')
hold on
plot(x_b(1,:),y_b(1,:),'g-s',x_v(1,:),y_v(1,:),'r-^')
axis([-0.08 0.04 0 0.12])

% Show key frames
% At 0, 50, 80, 100, 130, 150, 200, 250 [ms]
keyframes = [0 50 80 100 130 150 200 250]*(1/timestep)+1;
figure(iFig)
iFig=iFig+1;
subplot(2,4,1)
plot(x_b(keyframes(1),:),y_b(keyframes(1),:),'b-s',...
    x_v(keyframes(1),:),y_v(keyframes(1),:),'r-^')
title('0 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off

subplot(2,4,2)
plot(x_b(keyframes(2),:),y_b(keyframes(2),:),'b-s',...
    x_v(keyframes(2),:),y_v(keyframes(2),:),'r-^')
title('50 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off
subplot (2,4,3)
plot(x_b(keyframes(3),:),y_b(keyframes(3),:),'b-s',...
    x_v(keyframes(3),:),y_v(keyframes(3),:),'r-^')
title ('80 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off
subplot(2,4,4)
plot(x_b(keyframes(4),:),y_b(keyframes(4),:),'b-s',...
    x_v(keyframes(4),:),y_v(keyframes(4),:),'r-^')
title('100 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off

subplot(2,4,5)
plot(x_b(keyframes(5),:),y_b(keyframes(5),:),'b-s',...
    x_v(keyframes(5),:),y_v(keyframes(5),:),'r-^')
title('130 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off

subplot(2,4,6)
plot(x_b(keyframes(6),:),y_b(keyframes(6),:),'b-s',...
    x_v(keyframes(6),:),y_v(keyframes(6),:),'r-^')
title('150 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off

subplot(2,4,7)
plot(x_b(keyframes(7),:),y_b(keyframes(7),:),'b-s',...
    x_v(keyframes(7),:),y_v(keyframes(7),:),'r-^')
title('200 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off

subplot(2,4,8)
plot(x_b(keyframes(8),:),y_b(keyframes(8),:),'b-s',...
    x_v(keyframes(8),:),y_v(keyframes(8),:),'r-^')
title('250 ms')
axis([-0.08 0.04 0 0.12])
axis equal
axis off